# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import provider_pb2 as provider__pb2


class ProviderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMetrics = channel.unary_unary(
                '/batchx.provider.ProviderService/GetMetrics',
                request_serializer=provider__pb2.GetMetricsRequest.SerializeToString,
                response_deserializer=provider__pb2.GetMetricsResponse.FromString,
                )
        self.ListPayouts = channel.unary_unary(
                '/batchx.provider.ProviderService/ListPayouts',
                request_serializer=provider__pb2.ListPayoutsRequest.SerializeToString,
                response_deserializer=provider__pb2.ListPayoutsResponse.FromString,
                )
        self.ListRevenueByTools = channel.unary_unary(
                '/batchx.provider.ProviderService/ListRevenueByTools',
                request_serializer=provider__pb2.ListRevenueByToolsRequest.SerializeToString,
                response_deserializer=provider__pb2.ListRevenueByToolsResponse.FromString,
                )
        self.ListRevenueByCustomer = channel.unary_unary(
                '/batchx.provider.ProviderService/ListRevenueByCustomer',
                request_serializer=provider__pb2.ListRevenueByCustomerRequest.SerializeToString,
                response_deserializer=provider__pb2.ListRevenueByCustomerResponse.FromString,
                )


class ProviderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPayouts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRevenueByTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRevenueByCustomer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProviderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetrics,
                    request_deserializer=provider__pb2.GetMetricsRequest.FromString,
                    response_serializer=provider__pb2.GetMetricsResponse.SerializeToString,
            ),
            'ListPayouts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPayouts,
                    request_deserializer=provider__pb2.ListPayoutsRequest.FromString,
                    response_serializer=provider__pb2.ListPayoutsResponse.SerializeToString,
            ),
            'ListRevenueByTools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRevenueByTools,
                    request_deserializer=provider__pb2.ListRevenueByToolsRequest.FromString,
                    response_serializer=provider__pb2.ListRevenueByToolsResponse.SerializeToString,
            ),
            'ListRevenueByCustomer': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRevenueByCustomer,
                    request_deserializer=provider__pb2.ListRevenueByCustomerRequest.FromString,
                    response_serializer=provider__pb2.ListRevenueByCustomerResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.provider.ProviderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProviderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.provider.ProviderService/GetMetrics',
            provider__pb2.GetMetricsRequest.SerializeToString,
            provider__pb2.GetMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPayouts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.provider.ProviderService/ListPayouts',
            provider__pb2.ListPayoutsRequest.SerializeToString,
            provider__pb2.ListPayoutsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRevenueByTools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.provider.ProviderService/ListRevenueByTools',
            provider__pb2.ListRevenueByToolsRequest.SerializeToString,
            provider__pb2.ListRevenueByToolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRevenueByCustomer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.provider.ProviderService/ListRevenueByCustomer',
            provider__pb2.ListRevenueByCustomerRequest.SerializeToString,
            provider__pb2.ListRevenueByCustomerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tag.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ttag.proto\x12\nbatchx.tag\x1a\x0c\x63ommon.proto\"@\n\rGetTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\".\n\x0eGetTagResponse\x12\x1c\n\x03tag\x18\x01 \x01(\x0b\x32\x0f.batchx.tag.Tag\"1\n\x0eTagCoordinates\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x05\"M\n\x07TagData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x63olor\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\x08\"\x8f\x02\n\x03Tag\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.batchx.tag.TagData\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12(\n\x07metrics\x18\x04 \x01(\x0b\x32\x17.batchx.tag.Tag.Metrics\x12\x13\n\x0bts_creation\x18\x05 \x01(\x03\x12\x18\n\x10ts_last_modified\x18\x06 \x01(\x03\x1aI\n\x07Metrics\x12\x0e\n\x06images\x18\x01 \x01(\x05\x12\x0c\n\x04jobs\x18\x02 \x01(\x05\x12\x11\n\tworkflows\x18\x03 \x01(\x05\x12\r\n\x05\x66iles\x18\x04 \x01(\x05\"\xf9\x01\n\x1aListEnvironmentTagsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x17\n\x0fonly_categories\x18\x03 \x01(\x08\x12=\n\x06\x66ilter\x18\x04 \x01(\x0b\x32-.batchx.tag.ListEnvironmentTagsRequest.Filter\x1a^\n\x06\x46ilter\x12\x17\n\rused_in_tools\x18\x01 \x01(\x08H\x00\x12\x16\n\x0cused_in_jobs\x18\x02 \x01(\x08H\x00\x12\x1b\n\x11used_in_workflows\x18\x03 \x01(\x08H\x00\x42\x06\n\x04\x43\x61se\";\n\x1bListEnvironmentTagsResponse\x12\x1c\n\x03tag\x18\x01 \x03(\x0b\x32\x0f.batchx.tag.Tag\"J\n\x10\x43reateTagRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.batchx.tag.TagData\"D\n\x11\x43reateTagResponse\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\"T\n\x11\x44isableTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"C\n\x10\x44\x65leteTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\"\x13\n\x11\x44\x65leteTagResponse\"\x14\n\x12\x44isableTagResponse\"f\n\x10UpdateTagRequest\x12/\n\x0b\x63oordinates\x18\x01 \x01(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.batchx.tag.TagData\"\x13\n\x11UpdateTagResponse2\x8c\x04\n\nTagService\x12\x44\n\x06GetTag\x12\x19.batchx.tag.GetTagRequest\x1a\x1a.batchx.tag.GetTagResponse\"\x03\x90\x02\x01\x12k\n\x13ListEnvironmentTags\x12&.batchx.tag.ListEnvironmentTagsRequest\x1a\'.batchx.tag.ListEnvironmentTagsResponse\"\x03\x90\x02\x01\x12M\n\tCreateTag\x12\x1c.batchx.tag.CreateTagRequest\x1a\x1d.batchx.tag.CreateTagResponse\"\x03\x90\x02\x02\x12P\n\nDisableTag\x12\x1d.batchx.tag.DisableTagRequest\x1a\x1e.batchx.tag.DisableTagResponse\"\x03\x90\x02\x02\x12M\n\tDeleteTag\x12\x1c.batchx.tag.DeleteTagRequest\x1a\x1d.batchx.tag.DeleteTagResponse\"\x03\x90\x02\x02\x12M\n\tUpdateTag\x12\x1c.batchx.tag.UpdateTagRequest\x1a\x1d.batchx.tag.UpdateTagResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42\x1b\n\x0fio.batchx.protoB\x08TagProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tag_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\010TagProto'
  _TAGSERVICE._options = None
  _TAGSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _TAGSERVICE.methods_by_name['GetTag']._options = None
  _TAGSERVICE.methods_by_name['GetTag']._serialized_options = b'\220\002\001'
  _TAGSERVICE.methods_by_name['ListEnvironmentTags']._options = None
  _TAGSERVICE.methods_by_name['ListEnvironmentTags']._serialized_options = b'\220\002\001'
  _TAGSERVICE.methods_by_name['CreateTag']._options = None
  _TAGSERVICE.methods_by_name['CreateTag']._serialized_options = b'\220\002\002'
  _TAGSERVICE.methods_by_name['DisableTag']._options = None
  _TAGSERVICE.methods_by_name['DisableTag']._serialized_options = b'\220\002\002'
  _TAGSERVICE.methods_by_name['DeleteTag']._options = None
  _TAGSERVICE.methods_by_name['DeleteTag']._serialized_options = b'\220\002\002'
  _TAGSERVICE.methods_by_name['UpdateTag']._options = None
  _TAGSERVICE.methods_by_name['UpdateTag']._serialized_options = b'\220\002\002'
  _GETTAGREQUEST._serialized_start=39
  _GETTAGREQUEST._serialized_end=103
  _GETTAGRESPONSE._serialized_start=105
  _GETTAGRESPONSE._serialized_end=151
  _TAGCOORDINATES._serialized_start=153
  _TAGCOORDINATES._serialized_end=202
  _TAGDATA._serialized_start=204
  _TAGDATA._serialized_end=281
  _TAG._serialized_start=284
  _TAG._serialized_end=555
  _TAG_METRICS._serialized_start=482
  _TAG_METRICS._serialized_end=555
  _LISTENVIRONMENTTAGSREQUEST._serialized_start=558
  _LISTENVIRONMENTTAGSREQUEST._serialized_end=807
  _LISTENVIRONMENTTAGSREQUEST_FILTER._serialized_start=713
  _LISTENVIRONMENTTAGSREQUEST_FILTER._serialized_end=807
  _LISTENVIRONMENTTAGSRESPONSE._serialized_start=809
  _LISTENVIRONMENTTAGSRESPONSE._serialized_end=868
  _CREATETAGREQUEST._serialized_start=870
  _CREATETAGREQUEST._serialized_end=944
  _CREATETAGRESPONSE._serialized_start=946
  _CREATETAGRESPONSE._serialized_end=1014
  _DISABLETAGREQUEST._serialized_start=1016
  _DISABLETAGREQUEST._serialized_end=1100
  _DELETETAGREQUEST._serialized_start=1102
  _DELETETAGREQUEST._serialized_end=1169
  _DELETETAGRESPONSE._serialized_start=1171
  _DELETETAGRESPONSE._serialized_end=1190
  _DISABLETAGRESPONSE._serialized_start=1192
  _DISABLETAGRESPONSE._serialized_end=1212
  _UPDATETAGREQUEST._serialized_start=1214
  _UPDATETAGREQUEST._serialized_end=1316
  _UPDATETAGRESPONSE._serialized_start=1318
  _UPDATETAGRESPONSE._serialized_end=1337
  _TAGSERVICE._serialized_start=1340
  _TAGSERVICE._serialized_end=1864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import profile_pb2 as profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x0b\x62\x61tchx.user\x1a\x0c\x63ommon.proto\x1a\rprofile.proto\"e\n\x11UpdateUserRequest\x12&\n\tuser_data\x18\x01 \x01(\x0b\x32\x13.batchx.common.User\x12(\n\x07profile\x18\x02 \x01(\x0b\x32\x17.batchx.profile.Profile\"\x14\n\x12UpdateUserResponse\"7\n\x0eGetUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x17\n\x0finclude_profile\x18\x02 \x01(\x08\"\xb8\x02\n\x0fGetUserResponse\x12&\n\tuser_data\x18\x01 \x01(\x0b\x32\x13.batchx.common.User\x12\x36\n\x11organization_data\x18\x02 \x03(\x0b\x32\x1b.batchx.common.Organization\x12(\n\x07profile\x18\x03 \x01(\x0b\x32\x17.batchx.profile.Profile\x12@\n\nmembership\x18\x04 \x03(\x0b\x32,.batchx.user.GetUserResponse.MembershipEntry\x1aY\n\x0fMembershipEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.batchx.common.Organization.Membership:\x02\x38\x01\x32\xba\x01\n\x0bUserService\x12I\n\x07GetUser\x12\x1b.batchx.user.GetUserRequest\x1a\x1c.batchx.user.GetUserResponse\"\x03\x90\x02\x01\x12R\n\nUpdateUser\x12\x1e.batchx.user.UpdateUserRequest\x1a\x1f.batchx.user.UpdateUserResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\x05\x82\x97\"\x02\x10\x01\x42\x1c\n\x0fio.batchx.protoB\tUserProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\tUserProto'
  _GETUSERRESPONSE_MEMBERSHIPENTRY._options = None
  _GETUSERRESPONSE_MEMBERSHIPENTRY._serialized_options = b'8\001'
  _USERSERVICE._options = None
  _USERSERVICE._serialized_options = b'\202\227\"\002\010\005\202\227\"\002\020\001'
  _USERSERVICE.methods_by_name['GetUser']._options = None
  _USERSERVICE.methods_by_name['GetUser']._serialized_options = b'\220\002\001'
  _USERSERVICE.methods_by_name['UpdateUser']._options = None
  _USERSERVICE.methods_by_name['UpdateUser']._serialized_options = b'\220\002\002'
  _UPDATEUSERREQUEST._serialized_start=56
  _UPDATEUSERREQUEST._serialized_end=157
  _UPDATEUSERRESPONSE._serialized_start=159
  _UPDATEUSERRESPONSE._serialized_end=179
  _GETUSERREQUEST._serialized_start=181
  _GETUSERREQUEST._serialized_end=236
  _GETUSERRESPONSE._serialized_start=239
  _GETUSERRESPONSE._serialized_end=551
  _GETUSERRESPONSE_MEMBERSHIPENTRY._serialized_start=462
  _GETUSERRESPONSE_MEMBERSHIPENTRY._serialized_end=551
  _USERSERVICE._serialized_start=554
  _USERSERVICE._serialized_end=740
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: filesystem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import log_pb2 as log__pb2
from . import tag_pb2 as tag__pb2
from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x66ilesystem.proto\x12\x11\x62\x61tchx.filesystem\x1a\tlog.proto\x1a\ttag.proto\x1a\x0c\x63ommon.proto\"\xa9\x01\n\x10ShareFileRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1a\n\x12target_environment\x18\x03 \x01(\t\x12\x36\n\x04type\x18\x04 \x01(\x0e\x32(.batchx.filesystem.ShareFileRequest.Type\"\x1e\n\x04Type\x12\t\n\x05SHARE\x10\x00\x12\x0b\n\x07UNSHARE\x10\x01\"\x13\n\x11ShareFileResponse\"j\n\x14SetBlobStatusRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x1d.batchx.filesystem.BlobStatus\"\x17\n\x15SetBlobStatusResponse\"\xad\x05\n\x17ListBlobPointersRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\x12I\n\npagination\x18\x03 \x01(\x0b\x32\x35.batchx.filesystem.ListBlobPointersRequest.Pagination\x12G\n\tfiltering\x18\x04 \x01(\x0b\x32\x34.batchx.filesystem.ListBlobPointersRequest.Filtering\x12?\n\x05order\x18\x05 \x01(\x0b\x32\x30.batchx.filesystem.ListBlobPointersRequest.Order\x1a\xa3\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12N\n\x07memento\x18\x02 \x01(\x0b\x32=.batchx.filesystem.ListBlobPointersRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a\x17\n\x07Memento\x12\x0c\n\x04path\x18\x01 \x01(\t\x1aO\n\tFiltering\x12\r\n\x05owner\x18\x01 \x03(\t\x12\x33\n\x0bts_creation\x18\x02 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x1a\xa0\x01\n\x05Order\x12J\n\x08order_by\x18\x01 \x01(\x0e\x32\x38.batchx.filesystem.ListBlobPointersRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"\'\n\x07OrderBy\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bTS_CREATION\x10\x01\"\x8d\x02\n\x18ListBlobPointersResponse\x12%\n\x04\x66ile\x18\x01 \x03(\x0b\x32\x17.batchx.filesystem.File\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12G\n\x06owners\x18\x03 \x03(\x0b\x32\x37.batchx.filesystem.ListBlobPointersResponse.OwnersEntry\x12*\n\tpage_info\x18\x04 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x42\n\x0bOwnersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\"\xf4\x06\n\x10ListBlobsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x38\n\x05order\x18\x02 \x01(\x0b\x32).batchx.filesystem.ListBlobsRequest.Order\x12\x42\n\npagination\x18\x03 \x01(\x0b\x32..batchx.filesystem.ListBlobsRequest.Pagination\x12@\n\tfiltering\x18\x04 \x01(\x0b\x32-.batchx.filesystem.ListBlobsRequest.Filtering\x1a\xc9\x01\n\x05Order\x12\x43\n\x08order_by\x18\x01 \x01(\x0e\x32\x31.batchx.filesystem.ListBlobsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"W\n\x07OrderBy\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08POINTERS\x10\x01\x12\n\n\x06LENGTH\x10\x02\x12\x0f\n\x0bTS_CREATION\x10\x03\x12\x14\n\x10TS_LAST_MODIFIED\x10\x04\x1a\x9e\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12G\n\x07memento\x18\x02 \x01(\x0b\x32\x36.batchx.filesystem.ListBlobsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a\x19\n\x07Memento\x12\x0e\n\x06\x64igest\x18\x01 \x01(\t\x1a\x9d\x02\n\tFiltering\x12\x0c\n\x04user\x18\x01 \x03(\t\x12/\n\x08pointers\x18\x02 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12.\n\x06length\x18\x03 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x33\n\x0bts_creation\x18\x04 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x38\n\x10ts_last_modified\x18\x05 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\x0b\x62lob_status\x18\x06 \x03(\x0e\x32\x1d.batchx.filesystem.BlobStatus\"\xfc\x01\n\x11ListBlobsResponse\x12%\n\x04\x62lob\x18\x01 \x03(\x0b\x32\x17.batchx.filesystem.Blob\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12>\n\x05users\x18\x03 \x03(\x0b\x32/.batchx.filesystem.ListBlobsResponse.UsersEntry\x12*\n\tpage_info\x18\x04 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x41\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\"5\n\x0eGetBlobRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\"8\n\x0fGetBlobResponse\x12%\n\x04\x62lob\x18\x01 \x01(\x0b\x32\x17.batchx.filesystem.Blob\"\xf6\x02\n\x04\x42lob\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\x12\x10\n\x08pointers\x18\x03 \x01(\x05\x12\x0e\n\x06length\x18\x04 \x01(\x03\x12\x13\n\x0bts_creation\x18\x05 \x01(\x03\x12\x18\n\x10ts_last_modified\x18\x06 \x01(\x03\x12\x0c\n\x04user\x18\x07 \x01(\t\x12\x15\n\roriginal_path\x18\x08 \x01(\t\x12-\n\x06status\x18\t \x01(\x0e\x32\x1d.batchx.filesystem.BlobStatus\x12\x16\n\x0ets_archivation\x18\n \x01(\x03\x12\x33\n\tmeta_info\x18\x0b \x01(\x0b\x32 .batchx.filesystem.Blob.MetaInfo\x1aW\n\x08MetaInfo\x12\x0e\n\x06\x62inary\x18\x01 \x01(\x08\x12\x0c\n\x04gzip\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x65\x63ompressed_size\x18\x03 \x01(\x03\x12\x12\n\nline_count\x18\x04 \x01(\x03\"\x82\x08\n\x11ListFolderRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x41\n\tfiltering\x18\x04 \x01(\x0b\x32..batchx.filesystem.ListFolderRequest.Filtering\x12\x43\n\npagination\x18\x05 \x01(\x0b\x32/.batchx.filesystem.ListFolderRequest.Pagination\x12\x39\n\x05order\x18\x06 \x01(\x0b\x32*.batchx.filesystem.ListFolderRequest.Order\x12\x18\n\x10user_environment\x18\x07 \x01(\t\x1a\xe2\x02\n\tFiltering\x12\x0c\n\x04user\x18\x01 \x03(\t\x12\x12\n\nonly_ready\x18\x02 \x01(\x08\x12\x17\n\rexclude_files\x18\x03 \x01(\x08H\x00\x12\x19\n\x0f\x65xclude_folders\x18\x04 \x01(\x08H\x00\x12\'\n\x03tag\x18\x05 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x33\n\x0bts_creation\x18\x06 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x38\n\x10ts_last_modified\x18\x07 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12.\n\x06length\x18\x08 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12/\n\x08pointers\x18\t \x01(\x0b\x32\x1d.batchx.common.IntRangeFilterB\x06\n\x04Type\x1a\x9d\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12H\n\x07memento\x18\x02 \x01(\x0b\x32\x37.batchx.filesystem.ListFolderRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a\x17\n\x07Memento\x12\x0c\n\x04path\x18\x01 \x01(\t\x1a\xd4\x01\n\x05Order\x12\x44\n\x08order_by\x18\x01 \x01(\x0e\x32\x32.batchx.filesystem.ListFolderRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"a\n\x07OrderBy\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04PATH\x10\x01\x12\n\n\x06LENGTH\x10\x02\x12\x0f\n\x0bTS_CREATION\x10\x03\x12\x14\n\x10TS_LAST_MODIFIED\x10\x04\x12\x0c\n\x08POINTERS\x10\x05\"\x87\x02\n\x12ListFolderResponse\x12%\n\x04\x66ile\x18\x01 \x03(\x0b\x32\x17.batchx.filesystem.File\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x41\n\x06owners\x18\x04 \x03(\x0b\x32\x31.batchx.filesystem.ListFolderResponse.OwnersEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x42\n\x0bOwnersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01J\x04\x08\x03\x10\x04\"\xb2\x01\n\x13\x43reateFolderRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12G\n\tuser_data\x18\x03 \x03(\x0b\x32\x34.batchx.filesystem.CreateFolderRequest.UserDataEntry\x1a/\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x16\n\x14\x43reateFolderResponse\"8\n\x13\x44\x65leteFolderRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteFolderResponse\"6\n\x11\x44\x65leteFileRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"8\n\x12\x44\x65leteFileResponse\x12\x0e\n\x06\x64igest\x18\x01 \x01(\t\x12\x12\n\nother_refs\x18\x02 \x01(\x05\"3\n\x0eGetFileRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"b\n\x0fGetFileResponse\x12%\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x17.batchx.filesystem.File\x12\"\n\x05owner\x18\x03 \x01(\x0b\x32\x13.batchx.common.UserJ\x04\x08\x02\x10\x03\"\xe4\x02\n\x04\x46ile\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06\x66older\x18\x03 \x01(\x08\x12-\n\x08metadata\x18\x04 \x01(\x0b\x32\x1b.batchx.filesystem.Metadata\x12\x13\n\x0bts_creation\x18\x05 \x01(\x03\x12\x18\n\x10ts_last_modified\x18\x06 \x01(\x03\x12\r\n\x05owner\x18\x07 \x01(\t\x12.\n\x06status\x18\x08 \x01(\x0e\x32\x1e.batchx.filesystem.File.Status\x12\x10\n\x08pointers\x18\t \x01(\x05\x12\x32\n\x0b\x62lob_status\x18\n \x01(\x0e\x32\x1d.batchx.filesystem.BlobStatus\x12\x13\n\x0bshared_with\x18\x0b \x03(\t\"1\n\x06Status\x12\t\n\x05READY\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\r\n\tIMPORTING\x10\x02\"V\n\x19ReportUploadStatusRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x16\n\x0euploaded_bytes\x18\x03 \x01(\x03\"\x1c\n\x1aReportUploadStatusResponse\"8\n\x13\x43\x61ncelUploadRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x16\n\x14\x43\x61ncelUploadResponse\"\xe8\x01\n\x08Metadata\x12\x0e\n\x06length\x18\x01 \x01(\x03\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\x12<\n\tuser_data\x18\x03 \x03(\x0b\x32).batchx.filesystem.Metadata.UserDataEntry\x12\x13\n\x0bpart_length\x18\x04 \x01(\x03\x12\x38\n\x0e\x62lob_meta_info\x18\x05 \x01(\x0b\x32 .batchx.filesystem.Blob.MetaInfo\x1a/\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x16UploadPresignedRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12-\n\x08metadata\x18\x03 \x01(\x0b\x32\x1b.batchx.filesystem.Metadata\"\xa0\x01\n\x17UploadPresignedResponse\x12\x1a\n\x10\x61lready_uploaded\x18\x01 \x01(\x08H\x00\x12H\n\tpart_urls\x18\x02 \x01(\x0b\x32\x33.batchx.filesystem.UploadPresignedResponse.PartUrlsH\x00\x1a\x17\n\x08PartUrls\x12\x0b\n\x03url\x18\x01 \x03(\tB\x06\n\x04\x43\x61se\"h\n\x18\x44ownloadPresignedRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\t\x12\x0e\n\x04path\x18\x02 \x01(\tH\x00\x12\x10\n\x06\x64igest\x18\x04 \x01(\tH\x00\x42\x06\n\x04\x43\x61se\"W\n\x19\x44ownloadPresignedResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12-\n\x08metadata\x18\x02 \x01(\x0b\x32\x1b.batchx.filesystem.Metadata\"o\n\x0b\x43opyRequest\x12\x1a\n\x12source_environment\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x1a\n\x12target_environment\x18\x03 \x01(\t\x12\x13\n\x0btarget_path\x18\x04 \x01(\t\"L\n\x15\x43ompleteUploadRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08part_md5\x18\x03 \x03(\t\"\x18\n\x16\x43ompleteUploadResponse*x\n\nBlobStatus\x12\x08\n\x04LIVE\x10\x00\x12\x15\n\x11LIVE_AND_ARCHIVED\x10\x01\x12\x0c\n\x08\x41RCHIVED\x10\x02\x12\r\n\tARCHIVING\x10\n\x12\x0c\n\x08UNLIVING\x10\x0b\x12\r\n\tRESTORING\x10\x0c\x12\x0f\n\x0bUNARCHIVING\x10\r2\xc0\x0b\n\x11\x46ilesystemService\x12U\n\x07GetFile\x12!.batchx.filesystem.GetFileRequest\x1a\".batchx.filesystem.GetFileResponse\"\x03\x90\x02\x01\x12m\n\x0fUploadPresigned\x12).batchx.filesystem.UploadPresignedRequest\x1a*.batchx.filesystem.UploadPresignedResponse\"\x03\x90\x02\x02\x12v\n\x12ReportUploadStatus\x12,.batchx.filesystem.ReportUploadStatusRequest\x1a-.batchx.filesystem.ReportUploadStatusResponse\"\x03\x90\x02\x02\x12\x64\n\x0c\x43\x61ncelUpload\x12&.batchx.filesystem.CancelUploadRequest\x1a\'.batchx.filesystem.CancelUploadResponse\"\x03\x90\x02\x01\x12n\n\x0e\x43ompleteUpload\x12(.batchx.filesystem.CompleteUploadRequest\x1a).batchx.filesystem.CompleteUploadResponse\"\x07\x90\x02\x02\x88\xa6\x1d\x02\x12s\n\x11\x44ownloadPresigned\x12+.batchx.filesystem.DownloadPresignedRequest\x1a,.batchx.filesystem.DownloadPresignedResponse\"\x03\x90\x02\x02\x12^\n\nDeleteFile\x12$.batchx.filesystem.DeleteFileRequest\x1a%.batchx.filesystem.DeleteFileResponse\"\x03\x90\x02\x02\x12j\n\nListFolder\x12$.batchx.filesystem.ListFolderRequest\x1a%.batchx.filesystem.ListFolderResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x05\x82\xa6\x1d\x02\x10\x01\x12g\n\tListBlobs\x12#.batchx.filesystem.ListBlobsRequest\x1a$.batchx.filesystem.ListBlobsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x05\x82\xa6\x1d\x02\x10\x01\x12U\n\x07GetBlob\x12!.batchx.filesystem.GetBlobRequest\x1a\".batchx.filesystem.GetBlobResponse\"\x03\x90\x02\x01\x12g\n\rSetBlobStatus\x12\'.batchx.filesystem.SetBlobStatusRequest\x1a(.batchx.filesystem.SetBlobStatusResponse\"\x03\x90\x02\x01\x12|\n\x10ListBlobPointers\x12*.batchx.filesystem.ListBlobPointersRequest\x1a+.batchx.filesystem.ListBlobPointersResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x05\x82\xa6\x1d\x02\x10\x01\x12\x44\n\x04\x43opy\x12\x1e.batchx.filesystem.CopyRequest\x1a\x15.batchx.log.LogRecord\"\x03\x90\x02\x02\x30\x01\x12[\n\tShareFile\x12#.batchx.filesystem.ShareFileRequest\x1a$.batchx.filesystem.ShareFileResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\x32\x82\x97\"\x02\x10\x01\x42\"\n\x0fio.batchx.protoB\x0f\x46ilesystemProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filesystem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\017FilesystemProto'
  _LISTBLOBPOINTERSRESPONSE_OWNERSENTRY._options = None
  _LISTBLOBPOINTERSRESPONSE_OWNERSENTRY._serialized_options = b'8\001'
  _LISTBLOBSRESPONSE_USERSENTRY._options = None
  _LISTBLOBSRESPONSE_USERSENTRY._serialized_options = b'8\001'
  _LISTFOLDERRESPONSE_OWNERSENTRY._options = None
  _LISTFOLDERRESPONSE_OWNERSENTRY._serialized_options = b'8\001'
  _CREATEFOLDERREQUEST_USERDATAENTRY._options = None
  _CREATEFOLDERREQUEST_USERDATAENTRY._serialized_options = b'8\001'
  _METADATA_USERDATAENTRY._options = None
  _METADATA_USERDATAENTRY._serialized_options = b'8\001'
  _FILESYSTEMSERVICE._options = None
  _FILESYSTEMSERVICE._serialized_options = b'\202\227\"\002\0102\202\227\"\002\020\001'
  _FILESYSTEMSERVICE.methods_by_name['GetFile']._options = None
  _FILESYSTEMSERVICE.methods_by_name['GetFile']._serialized_options = b'\220\002\001'
  _FILESYSTEMSERVICE.methods_by_name['UploadPresigned']._options = None
  _FILESYSTEMSERVICE.methods_by_name['UploadPresigned']._serialized_options = b'\220\002\002'
  _FILESYSTEMSERVICE.methods_by_name['ReportUploadStatus']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ReportUploadStatus']._serialized_options = b'\220\002\002'
  _FILESYSTEMSERVICE.methods_by_name['CancelUpload']._options = None
  _FILESYSTEMSERVICE.methods_by_name['CancelUpload']._serialized_options = b'\220\002\001'
  _FILESYSTEMSERVICE.methods_by_name['CompleteUpload']._options = None
  _FILESYSTEMSERVICE.methods_by_name['CompleteUpload']._serialized_options = b'\220\002\002\210\246\035\002'
  _FILESYSTEMSERVICE.methods_by_name['DownloadPresigned']._options = None
  _FILESYSTEMSERVICE.methods_by_name['DownloadPresigned']._serialized_options = b'\220\002\002'
  _FILESYSTEMSERVICE.methods_by_name['DeleteFile']._options = None
  _FILESYSTEMSERVICE.methods_by_name['DeleteFile']._serialized_options = b'\220\002\002'
  _FILESYSTEMSERVICE.methods_by_name['ListFolder']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ListFolder']._serialized_options = b'\220\002\001\202\246\035\002\010\005\202\246\035\002\020\001'
  _FILESYSTEMSERVICE.methods_by_name['ListBlobs']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ListBlobs']._serialized_options = b'\220\002\001\202\246\035\002\010\005\202\246\035\002\020\001'
  _FILESYSTEMSERVICE.methods_by_name['GetBlob']._options = None
  _FILESYSTEMSERVICE.methods_by_name['GetBlob']._serialized_options = b'\220\002\001'
  _FILESYSTEMSERVICE.methods_by_name['SetBlobStatus']._options = None
  _FILESYSTEMSERVICE.methods_by_name['SetBlobStatus']._serialized_options = b'\220\002\001'
  _FILESYSTEMSERVICE.methods_by_name['ListBlobPointers']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ListBlobPointers']._serialized_options = b'\220\002\001\202\246\035\002\010\005\202\246\035\002\020\001'
  _FILESYSTEMSERVICE.methods_by_name['Copy']._options = None
  _FILESYSTEMSERVICE.methods_by_name['Copy']._serialized_options = b'\220\002\002'
  _FILESYSTEMSERVICE.methods_by_name['ShareFile']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ShareFile']._serialized_options = b'\220\002\002'
  _BLOBSTATUS._serialized_start=6319
  _BLOBSTATUS._serialized_end=6439
  _SHAREFILEREQUEST._serialized_start=76
  _SHAREFILEREQUEST._serialized_end=245
  _SHAREFILEREQUEST_TYPE._serialized_start=215
  _SHAREFILEREQUEST_TYPE._serialized_end=245
  _SHAREFILERESPONSE._serialized_start=247
  _SHAREFILERESPONSE._serialized_end=266
  _SETBLOBSTATUSREQUEST._serialized_start=268
  _SETBLOBSTATUSREQUEST._serialized_end=374
  _SETBLOBSTATUSRESPONSE._serialized_start=376
  _SETBLOBSTATUSRESPONSE._serialized_end=399
  _LISTBLOBPOINTERSREQUEST._serialized_start=402
  _LISTBLOBPOINTERSREQUEST._serialized_end=1087
  _LISTBLOBPOINTERSREQUEST_PAGINATION._serialized_start=680
  _LISTBLOBPOINTERSREQUEST_PAGINATION._serialized_end=843
  _LISTBLOBPOINTERSREQUEST_PAGINATION_MEMENTO._serialized_start=820
  _LISTBLOBPOINTERSREQUEST_PAGINATION_MEMENTO._serialized_end=843
  _LISTBLOBPOINTERSREQUEST_FILTERING._serialized_start=845
  _LISTBLOBPOINTERSREQUEST_FILTERING._serialized_end=924
  _LISTBLOBPOINTERSREQUEST_ORDER._serialized_start=927
  _LISTBLOBPOINTERSREQUEST_ORDER._serialized_end=1087
  _LISTBLOBPOINTERSREQUEST_ORDER_ORDERBY._serialized_start=1048
  _LISTBLOBPOINTERSREQUEST_ORDER_ORDERBY._serialized_end=1087
  _LISTBLOBPOINTERSRESPONSE._serialized_start=1090
  _LISTBLOBPOINTERSRESPONSE._serialized_end=1359
  _LISTBLOBPOINTERSRESPONSE_OWNERSENTRY._serialized_start=1293
  _LISTBLOBPOINTERSRESPONSE_OWNERSENTRY._serialized_end=1359
  _LISTBLOBSREQUEST._serialized_start=1362
  _LISTBLOBSREQUEST._serialized_end=2246
  _LISTBLOBSREQUEST_ORDER._serialized_start=1596
  _LISTBLOBSREQUEST_ORDER._serialized_end=1797
  _LISTBLOBSREQUEST_ORDER_ORDERBY._serialized_start=1710
  _LISTBLOBSREQUEST_ORDER_ORDERBY._serialized_end=1797
  _LISTBLOBSREQUEST_PAGINATION._serialized_start=1800
  _LISTBLOBSREQUEST_PAGINATION._serialized_end=1958
  _LISTBLOBSREQUEST_PAGINATION_MEMENTO._serialized_start=1933
  _LISTBLOBSREQUEST_PAGINATION_MEMENTO._serialized_end=1958
  _LISTBLOBSREQUEST_FILTERING._serialized_start=1961
  _LISTBLOBSREQUEST_FILTERING._serialized_end=2246
  _LISTBLOBSRESPONSE._serialized_start=2249
  _LISTBLOBSRESPONSE._serialized_end=2501
  _LISTBLOBSRESPONSE_USERSENTRY._serialized_start=2436
  _LISTBLOBSRESPONSE_USERSENTRY._serialized_end=2501
  _GETBLOBREQUEST._serialized_start=2503
  _GETBLOBREQUEST._serialized_end=2556
  _GETBLOBRESPONSE._serialized_start=2558
  _GETBLOBRESPONSE._serialized_end=2614
  _BLOB._serialized_start=2617
  _BLOB._serialized_end=2991
  _BLOB_METAINFO._serialized_start=2904
  _BLOB_METAINFO._serialized_end=2991
  _LISTFOLDERREQUEST._serialized_start=2994
  _LISTFOLDERREQUEST._serialized_end=4020
  _LISTFOLDERREQUEST_FILTERING._serialized_start=3291
  _LISTFOLDERREQUEST_FILTERING._serialized_end=3645
  _LISTFOLDERREQUEST_PAGINATION._serialized_start=3648
  _LISTFOLDERREQUEST_PAGINATION._serialized_end=3805
  _LISTFOLDERREQUEST_PAGINATION_MEMENTO._serialized_start=820
  _LISTFOLDERREQUEST_PAGINATION_MEMENTO._serialized_end=843
  _LISTFOLDERREQUEST_ORDER._serialized_start=3808
  _LISTFOLDERREQUEST_ORDER._serialized_end=4020
  _LISTFOLDERREQUEST_ORDER_ORDERBY._serialized_start=3923
  _LISTFOLDERREQUEST_ORDER_ORDERBY._serialized_end=4020
  _LISTFOLDERRESPONSE._serialized_start=4023
  _LISTFOLDERRESPONSE._serialized_end=4286
  _LISTFOLDERRESPONSE_OWNERSENTRY._serialized_start=1293
  _LISTFOLDERRESPONSE_OWNERSENTRY._serialized_end=1359
  _CREATEFOLDERREQUEST._serialized_start=4289
  _CREATEFOLDERREQUEST._serialized_end=4467
  _CREATEFOLDERREQUEST_USERDATAENTRY._serialized_start=4420
  _CREATEFOLDERREQUEST_USERDATAENTRY._serialized_end=4467
  _CREATEFOLDERRESPONSE._serialized_start=4469
  _CREATEFOLDERRESPONSE._serialized_end=4491
  _DELETEFOLDERREQUEST._serialized_start=4493
  _DELETEFOLDERREQUEST._serialized_end=4549
  _DELETEFOLDERRESPONSE._serialized_start=4551
  _DELETEFOLDERRESPONSE._serialized_end=4573
  _DELETEFILEREQUEST._serialized_start=4575
  _DELETEFILEREQUEST._serialized_end=4629
  _DELETEFILERESPONSE._serialized_start=4631
  _DELETEFILERESPONSE._serialized_end=4687
  _GETFILEREQUEST._serialized_start=4689
  _GETFILEREQUEST._serialized_end=4740
  _GETFILERESPONSE._serialized_start=4742
  _GETFILERESPONSE._serialized_end=4840
  _FILE._serialized_start=4843
  _FILE._serialized_end=5199
  _FILE_STATUS._serialized_start=5150
  _FILE_STATUS._serialized_end=5199
  _REPORTUPLOADSTATUSREQUEST._serialized_start=5201
  _REPORTUPLOADSTATUSREQUEST._serialized_end=5287
  _REPORTUPLOADSTATUSRESPONSE._serialized_start=5289
  _REPORTUPLOADSTATUSRESPONSE._serialized_end=5317
  _CANCELUPLOADREQUEST._serialized_start=5319
  _CANCELUPLOADREQUEST._serialized_end=5375
  _CANCELUPLOADRESPONSE._serialized_start=5377
  _CANCELUPLOADRESPONSE._serialized_end=5399
  _METADATA._serialized_start=5402
  _METADATA._serialized_end=5634
  _METADATA_USERDATAENTRY._serialized_start=4420
  _METADATA_USERDATAENTRY._serialized_end=4467
  _UPLOADPRESIGNEDREQUEST._serialized_start=5636
  _UPLOADPRESIGNEDREQUEST._serialized_end=5742
  _UPLOADPRESIGNEDRESPONSE._serialized_start=5745
  _UPLOADPRESIGNEDRESPONSE._serialized_end=5905
  _UPLOADPRESIGNEDRESPONSE_PARTURLS._serialized_start=5874
  _UPLOADPRESIGNEDRESPONSE_PARTURLS._serialized_end=5897
  _DOWNLOADPRESIGNEDREQUEST._serialized_start=5907
  _DOWNLOADPRESIGNEDREQUEST._serialized_end=6011
  _DOWNLOADPRESIGNEDRESPONSE._serialized_start=6013
  _DOWNLOADPRESIGNEDRESPONSE._serialized_end=6100
  _COPYREQUEST._serialized_start=6102
  _COPYREQUEST._serialized_end=6213
  _COMPLETEUPLOADREQUEST._serialized_start=6215
  _COMPLETEUPLOADREQUEST._serialized_end=6291
  _COMPLETEUPLOADRESPONSE._serialized_start=6293
  _COMPLETEUPLOADRESPONSE._serialized_end=6317
  _FILESYSTEMSERVICE._serialized_start=6442
  _FILESYSTEMSERVICE._serialized_end=7914
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import admin_pb2 as admin__pb2


class AdminServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateUser = channel.unary_unary(
                '/batchx.admin.AdminService/CreateUser',
                request_serializer=admin__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=admin__pb2.CreateUserResponse.FromString,
                )
        self.RemoveUser = channel.unary_unary(
                '/batchx.admin.AdminService/RemoveUser',
                request_serializer=admin__pb2.RemoveUserRequest.SerializeToString,
                response_deserializer=admin__pb2.RemoveUserResponse.FromString,
                )
        self.CreateOrg = channel.unary_unary(
                '/batchx.admin.AdminService/CreateOrg',
                request_serializer=admin__pb2.CreateOrgRequest.SerializeToString,
                response_deserializer=admin__pb2.CreateOrgResponse.FromString,
                )
        self.CreateMembership = channel.unary_unary(
                '/batchx.admin.AdminService/CreateMembership',
                request_serializer=admin__pb2.CreateMembershipRequest.SerializeToString,
                response_deserializer=admin__pb2.CreateMembershipResponse.FromString,
                )
        self.AddEnvironmentCredits = channel.unary_unary(
                '/batchx.admin.AdminService/AddEnvironmentCredits',
                request_serializer=admin__pb2.AddEnvironmentCreditsRequest.SerializeToString,
                response_deserializer=admin__pb2.AddEnvironmentCreditsResponse.FromString,
                )
        self.SetGlobalProperty = channel.unary_unary(
                '/batchx.admin.AdminService/SetGlobalProperty',
                request_serializer=admin__pb2.SetGlobalPropertyRequest.SerializeToString,
                response_deserializer=admin__pb2.SetGlobalPropertyResponse.FromString,
                )
        self.GetGlobalProperties = channel.unary_unary(
                '/batchx.admin.AdminService/GetGlobalProperties',
                request_serializer=admin__pb2.GetGlobalPropertiesRequest.SerializeToString,
                response_deserializer=admin__pb2.GetGlobalPropertiesResponse.FromString,
                )
        self.GeneratePromoCode = channel.unary_unary(
                '/batchx.admin.AdminService/GeneratePromoCode',
                request_serializer=admin__pb2.GeneratePromoCodeRequest.SerializeToString,
                response_deserializer=admin__pb2.GeneratePromoCodeResponse.FromString,
                )


class AdminServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMembership(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddEnvironmentCredits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetGlobalProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGlobalProperties(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeneratePromoCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=admin__pb2.CreateUserRequest.FromString,
                    response_serializer=admin__pb2.CreateUserResponse.SerializeToString,
            ),
            'RemoveUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveUser,
                    request_deserializer=admin__pb2.RemoveUserRequest.FromString,
                    response_serializer=admin__pb2.RemoveUserResponse.SerializeToString,
            ),
            'CreateOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrg,
                    request_deserializer=admin__pb2.CreateOrgRequest.FromString,
                    response_serializer=admin__pb2.CreateOrgResponse.SerializeToString,
            ),
            'CreateMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMembership,
                    request_deserializer=admin__pb2.CreateMembershipRequest.FromString,
                    response_serializer=admin__pb2.CreateMembershipResponse.SerializeToString,
            ),
            'AddEnvironmentCredits': grpc.unary_unary_rpc_method_handler(
                    servicer.AddEnvironmentCredits,
                    request_deserializer=admin__pb2.AddEnvironmentCreditsRequest.FromString,
                    response_serializer=admin__pb2.AddEnvironmentCreditsResponse.SerializeToString,
            ),
            'SetGlobalProperty': grpc.unary_unary_rpc_method_handler(
                    servicer.SetGlobalProperty,
                    request_deserializer=admin__pb2.SetGlobalPropertyRequest.FromString,
                    response_serializer=admin__pb2.SetGlobalPropertyResponse.SerializeToString,
            ),
            'GetGlobalProperties': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGlobalProperties,
                    request_deserializer=admin__pb2.GetGlobalPropertiesRequest.FromString,
                    response_serializer=admin__pb2.GetGlobalPropertiesResponse.SerializeToString,
            ),
            'GeneratePromoCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GeneratePromoCode,
                    request_deserializer=admin__pb2.GeneratePromoCodeRequest.FromString,
                    response_serializer=admin__pb2.GeneratePromoCodeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.admin.AdminService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AdminService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/CreateUser',
            admin__pb2.CreateUserRequest.SerializeToString,
            admin__pb2.CreateUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/RemoveUser',
            admin__pb2.RemoveUserRequest.SerializeToString,
            admin__pb2.RemoveUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/CreateOrg',
            admin__pb2.CreateOrgRequest.SerializeToString,
            admin__pb2.CreateOrgResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/CreateMembership',
            admin__pb2.CreateMembershipRequest.SerializeToString,
            admin__pb2.CreateMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddEnvironmentCredits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/AddEnvironmentCredits',
            admin__pb2.AddEnvironmentCreditsRequest.SerializeToString,
            admin__pb2.AddEnvironmentCreditsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetGlobalProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/SetGlobalProperty',
            admin__pb2.SetGlobalPropertyRequest.SerializeToString,
            admin__pb2.SetGlobalPropertyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGlobalProperties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/GetGlobalProperties',
            admin__pb2.GetGlobalPropertiesRequest.SerializeToString,
            admin__pb2.GetGlobalPropertiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeneratePromoCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.admin.AdminService/GeneratePromoCode',
            admin__pb2.GeneratePromoCodeRequest.SerializeToString,
            admin__pb2.GeneratePromoCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: provider.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eprovider.proto\x12\x0f\x62\x61tchx.provider\x1a\x0c\x63ommon.proto\")\n\x12ListPayoutsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\"\x88\x01\n\x06Payout\x12\x16\n\x0ets_period_from\x18\x01 \x01(\x03\x12\x14\n\x0cts_period_to\x18\x02 \x01(\x03\x12\x12\n\nts_deposit\x18\x03 \x01(\x03\x12\x12\n\ntotal_fees\x18\x04 \x01(\x05\x12\x19\n\x11\x62\x61tchx_commission\x18\x05 \x01(\x05\x12\r\n\x05total\x18\x06 \x01(\x05\">\n\x13ListPayoutsResponse\x12\'\n\x06payout\x18\x01 \x03(\x0b\x32\x17.batchx.provider.Payout\"H\n\x11GetMetricsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07ts_from\x18\x02 \x01(\x03\x12\r\n\x05ts_to\x18\x03 \x01(\x03\"\xc5\x03\n\x12GetMetricsResponse\x12\x18\n\x10\x61\x63tive_consumers\x18\x01 \x01(\x05\x12\x11\n\ttool_fees\x18\x02 \x01(\x03\x12\x45\n\x0ctool_metrics\x18\x03 \x01(\x0b\x32/.batchx.provider.GetMetricsResponse.ToolMetrics\x12\x43\n\x0bjob_metrics\x18\x04 \x01(\x0b\x32..batchx.provider.GetMetricsResponse.JobMetrics\x1aS\n\x0bToolMetrics\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x05\x12\x19\n\x11\x63umulative_cloned\x18\x02 \x01(\x05\x12\x19\n\x11\x63umulative_shared\x18\x03 \x01(\x05\x1a\xa0\x01\n\nJobMetrics\x12[\n\x0fstatus_counters\x18\x01 \x03(\x0b\x32\x42.batchx.provider.GetMetricsResponse.JobMetrics.StatusCountersEntry\x1a\x35\n\x13StatusCountersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xca\x01\n\x19ListRevenueByToolsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07ts_from\x18\x02 \x01(\x03\x12\r\n\x05ts_to\x18\x03 \x01(\x03\x12I\n\npagination\x18\x04 \x01(\x0b\x32\x35.batchx.provider.ListRevenueByToolsRequest.Pagination\x1a-\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0c\n\x04page\x18\x02 \x01(\x05\"\x83\x02\n\x1aListRevenueByToolsResponse\x12\x44\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x35.batchx.provider.ListRevenueByToolsResponse.ToolEntry\x12\x15\n\rtotal_entries\x18\x02 \x01(\x05\x1a\x87\x01\n\tToolEntry\x12\x11\n\ttool_name\x18\x01 \x01(\t\x12\r\n\x05users\x18\x02 \x01(\x05\x12\x11\n\tsucceeded\x18\x03 \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\x04 \x01(\x03\x12\r\n\x05total\x18\x05 \x01(\x03\x12\x0c\n\x04\x66\x65\x65s\x18\x06 \x01(\x05\x12\x18\n\x10\x63omputation_cost\x18\x07 \x01(\x05\"\xd0\x01\n\x1cListRevenueByCustomerRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07ts_from\x18\x02 \x01(\x03\x12\r\n\x05ts_to\x18\x03 \x01(\x03\x12L\n\npagination\x18\x04 \x01(\x0b\x32\x38.batchx.provider.ListRevenueByCustomerRequest.Pagination\x1a-\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0c\n\x04page\x18\x02 \x01(\x05\"\xbd\x04\n\x1dListRevenueByCustomerResponse\x12K\n\x05\x65ntry\x18\x01 \x03(\x0b\x32<.batchx.provider.ListRevenueByCustomerResponse.CustomerEntry\x12O\n\tuser_data\x18\x02 \x03(\x0b\x32<.batchx.provider.ListRevenueByCustomerResponse.UserDataEntry\x12M\n\x08org_data\x18\x03 \x03(\x0b\x32;.batchx.provider.ListRevenueByCustomerResponse.OrgDataEntry\x12\x15\n\rtotal_entries\x18\x04 \x01(\x05\x1a\x84\x01\n\rCustomerEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05tools\x18\x02 \x01(\x05\x12\x11\n\tsucceeded\x18\x03 \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\x04 \x01(\x03\x12\r\n\x05total\x18\x05 \x01(\x03\x12\x0c\n\x04\x66\x65\x65s\x18\x06 \x01(\x05\x12\x18\n\x10\x63omputation_cost\x18\x07 \x01(\x05\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\x1aK\n\x0cOrgDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.batchx.common.Organization:\x02\x38\x01\x32\xcb\x03\n\x0fProviderService\x12Z\n\nGetMetrics\x12\".batchx.provider.GetMetricsRequest\x1a#.batchx.provider.GetMetricsResponse\"\x03\x90\x02\x01\x12]\n\x0bListPayouts\x12#.batchx.provider.ListPayoutsRequest\x1a$.batchx.provider.ListPayoutsResponse\"\x03\x90\x02\x01\x12r\n\x12ListRevenueByTools\x12*.batchx.provider.ListRevenueByToolsRequest\x1a+.batchx.provider.ListRevenueByToolsResponse\"\x03\x90\x02\x01\x12{\n\x15ListRevenueByCustomer\x12-.batchx.provider.ListRevenueByCustomerRequest\x1a..batchx.provider.ListRevenueByCustomerResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42 \n\x0fio.batchx.protoB\rProviderProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'provider_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\rProviderProto'
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._options = None
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_options = b'8\001'
  _LISTREVENUEBYCUSTOMERRESPONSE_USERDATAENTRY._options = None
  _LISTREVENUEBYCUSTOMERRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _LISTREVENUEBYCUSTOMERRESPONSE_ORGDATAENTRY._options = None
  _LISTREVENUEBYCUSTOMERRESPONSE_ORGDATAENTRY._serialized_options = b'8\001'
  _PROVIDERSERVICE._options = None
  _PROVIDERSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _PROVIDERSERVICE.methods_by_name['GetMetrics']._options = None
  _PROVIDERSERVICE.methods_by_name['GetMetrics']._serialized_options = b'\220\002\001'
  _PROVIDERSERVICE.methods_by_name['ListPayouts']._options = None
  _PROVIDERSERVICE.methods_by_name['ListPayouts']._serialized_options = b'\220\002\001'
  _PROVIDERSERVICE.methods_by_name['ListRevenueByTools']._options = None
  _PROVIDERSERVICE.methods_by_name['ListRevenueByTools']._serialized_options = b'\220\002\001'
  _PROVIDERSERVICE.methods_by_name['ListRevenueByCustomer']._options = None
  _PROVIDERSERVICE.methods_by_name['ListRevenueByCustomer']._serialized_options = b'\220\002\001'
  _LISTPAYOUTSREQUEST._serialized_start=49
  _LISTPAYOUTSREQUEST._serialized_end=90
  _PAYOUT._serialized_start=93
  _PAYOUT._serialized_end=229
  _LISTPAYOUTSRESPONSE._serialized_start=231
  _LISTPAYOUTSRESPONSE._serialized_end=293
  _GETMETRICSREQUEST._serialized_start=295
  _GETMETRICSREQUEST._serialized_end=367
  _GETMETRICSRESPONSE._serialized_start=370
  _GETMETRICSRESPONSE._serialized_end=823
  _GETMETRICSRESPONSE_TOOLMETRICS._serialized_start=577
  _GETMETRICSRESPONSE_TOOLMETRICS._serialized_end=660
  _GETMETRICSRESPONSE_JOBMETRICS._serialized_start=663
  _GETMETRICSRESPONSE_JOBMETRICS._serialized_end=823
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_start=770
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_end=823
  _LISTREVENUEBYTOOLSREQUEST._serialized_start=826
  _LISTREVENUEBYTOOLSREQUEST._serialized_end=1028
  _LISTREVENUEBYTOOLSREQUEST_PAGINATION._serialized_start=983
  _LISTREVENUEBYTOOLSREQUEST_PAGINATION._serialized_end=1028
  _LISTREVENUEBYTOOLSRESPONSE._serialized_start=1031
  _LISTREVENUEBYTOOLSRESPONSE._serialized_end=1290
  _LISTREVENUEBYTOOLSRESPONSE_TOOLENTRY._serialized_start=1155
  _LISTREVENUEBYTOOLSRESPONSE_TOOLENTRY._serialized_end=1290
  _LISTREVENUEBYCUSTOMERREQUEST._serialized_start=1293
  _LISTREVENUEBYCUSTOMERREQUEST._serialized_end=1501
  _LISTREVENUEBYCUSTOMERREQUEST_PAGINATION._serialized_start=983
  _LISTREVENUEBYCUSTOMERREQUEST_PAGINATION._serialized_end=1028
  _LISTREVENUEBYCUSTOMERRESPONSE._serialized_start=1504
  _LISTREVENUEBYCUSTOMERRESPONSE._serialized_end=2077
  _LISTREVENUEBYCUSTOMERRESPONSE_CUSTOMERENTRY._serialized_start=1798
  _LISTREVENUEBYCUSTOMERRESPONSE_CUSTOMERENTRY._serialized_end=1930
  _LISTREVENUEBYCUSTOMERRESPONSE_USERDATAENTRY._serialized_start=1932
  _LISTREVENUEBYCUSTOMERRESPONSE_USERDATAENTRY._serialized_end=2000
  _LISTREVENUEBYCUSTOMERRESPONSE_ORGDATAENTRY._serialized_start=2002
  _LISTREVENUEBYCUSTOMERRESPONSE_ORGDATAENTRY._serialized_end=2077
  _PROVIDERSERVICE._serialized_start=2080
  _PROVIDERSERVICE._serialized_end=2539
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import filesystem_pb2 as filesystem__pb2
from . import log_pb2 as log__pb2


class FilesystemServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFile = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/GetFile',
                request_serializer=filesystem__pb2.GetFileRequest.SerializeToString,
                response_deserializer=filesystem__pb2.GetFileResponse.FromString,
                )
        self.UploadPresigned = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/UploadPresigned',
                request_serializer=filesystem__pb2.UploadPresignedRequest.SerializeToString,
                response_deserializer=filesystem__pb2.UploadPresignedResponse.FromString,
                )
        self.ReportUploadStatus = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/ReportUploadStatus',
                request_serializer=filesystem__pb2.ReportUploadStatusRequest.SerializeToString,
                response_deserializer=filesystem__pb2.ReportUploadStatusResponse.FromString,
                )
        self.CancelUpload = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/CancelUpload',
                request_serializer=filesystem__pb2.CancelUploadRequest.SerializeToString,
                response_deserializer=filesystem__pb2.CancelUploadResponse.FromString,
                )
        self.CompleteUpload = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/CompleteUpload',
                request_serializer=filesystem__pb2.CompleteUploadRequest.SerializeToString,
                response_deserializer=filesystem__pb2.CompleteUploadResponse.FromString,
                )
        self.DownloadPresigned = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/DownloadPresigned',
                request_serializer=filesystem__pb2.DownloadPresignedRequest.SerializeToString,
                response_deserializer=filesystem__pb2.DownloadPresignedResponse.FromString,
                )
        self.DeleteFile = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/DeleteFile',
                request_serializer=filesystem__pb2.DeleteFileRequest.SerializeToString,
                response_deserializer=filesystem__pb2.DeleteFileResponse.FromString,
                )
        self.ListFolder = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/ListFolder',
                request_serializer=filesystem__pb2.ListFolderRequest.SerializeToString,
                response_deserializer=filesystem__pb2.ListFolderResponse.FromString,
                )
        self.ListBlobs = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/ListBlobs',
                request_serializer=filesystem__pb2.ListBlobsRequest.SerializeToString,
                response_deserializer=filesystem__pb2.ListBlobsResponse.FromString,
                )
        self.GetBlob = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/GetBlob',
                request_serializer=filesystem__pb2.GetBlobRequest.SerializeToString,
                response_deserializer=filesystem__pb2.GetBlobResponse.FromString,
                )
        self.SetBlobStatus = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/SetBlobStatus',
                request_serializer=filesystem__pb2.SetBlobStatusRequest.SerializeToString,
                response_deserializer=filesystem__pb2.SetBlobStatusResponse.FromString,
                )
        self.ListBlobPointers = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/ListBlobPointers',
                request_serializer=filesystem__pb2.ListBlobPointersRequest.SerializeToString,
                response_deserializer=filesystem__pb2.ListBlobPointersResponse.FromString,
                )
        self.Copy = channel.unary_stream(
                '/batchx.filesystem.FilesystemService/Copy',
                request_serializer=filesystem__pb2.CopyRequest.SerializeToString,
                response_deserializer=log__pb2.LogRecord.FromString,
                )
        self.ShareFile = channel.unary_unary(
                '/batchx.filesystem.FilesystemService/ShareFile',
                request_serializer=filesystem__pb2.ShareFileRequest.SerializeToString,
                response_deserializer=filesystem__pb2.ShareFileResponse.FromString,
                )


class FilesystemServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadPresigned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportUploadStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadPresigned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFolder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBlobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBlobStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBlobPointers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Copy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShareFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FilesystemServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFile,
                    request_deserializer=filesystem__pb2.GetFileRequest.FromString,
                    response_serializer=filesystem__pb2.GetFileResponse.SerializeToString,
            ),
            'UploadPresigned': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadPresigned,
                    request_deserializer=filesystem__pb2.UploadPresignedRequest.FromString,
                    response_serializer=filesystem__pb2.UploadPresignedResponse.SerializeToString,
            ),
            'ReportUploadStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportUploadStatus,
                    request_deserializer=filesystem__pb2.ReportUploadStatusRequest.FromString,
                    response_serializer=filesystem__pb2.ReportUploadStatusResponse.SerializeToString,
            ),
            'CancelUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelUpload,
                    request_deserializer=filesystem__pb2.CancelUploadRequest.FromString,
                    response_serializer=filesystem__pb2.CancelUploadResponse.SerializeToString,
            ),
            'CompleteUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteUpload,
                    request_deserializer=filesystem__pb2.CompleteUploadRequest.FromString,
                    response_serializer=filesystem__pb2.CompleteUploadResponse.SerializeToString,
            ),
            'DownloadPresigned': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadPresigned,
                    request_deserializer=filesystem__pb2.DownloadPresignedRequest.FromString,
                    response_serializer=filesystem__pb2.DownloadPresignedResponse.SerializeToString,
            ),
            'DeleteFile': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFile,
                    request_deserializer=filesystem__pb2.DeleteFileRequest.FromString,
                    response_serializer=filesystem__pb2.DeleteFileResponse.SerializeToString,
            ),
            'ListFolder': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFolder,
                    request_deserializer=filesystem__pb2.ListFolderRequest.FromString,
                    response_serializer=filesystem__pb2.ListFolderResponse.SerializeToString,
            ),
            'ListBlobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBlobs,
                    request_deserializer=filesystem__pb2.ListBlobsRequest.FromString,
                    response_serializer=filesystem__pb2.ListBlobsResponse.SerializeToString,
            ),
            'GetBlob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlob,
                    request_deserializer=filesystem__pb2.GetBlobRequest.FromString,
                    response_serializer=filesystem__pb2.GetBlobResponse.SerializeToString,
            ),
            'SetBlobStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBlobStatus,
                    request_deserializer=filesystem__pb2.SetBlobStatusRequest.FromString,
                    response_serializer=filesystem__pb2.SetBlobStatusResponse.SerializeToString,
            ),
            'ListBlobPointers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBlobPointers,
                    request_deserializer=filesystem__pb2.ListBlobPointersRequest.FromString,
                    response_serializer=filesystem__pb2.ListBlobPointersResponse.SerializeToString,
            ),
            'Copy': grpc.unary_stream_rpc_method_handler(
                    servicer.Copy,
                    request_deserializer=filesystem__pb2.CopyRequest.FromString,
                    response_serializer=log__pb2.LogRecord.SerializeToString,
            ),
            'ShareFile': grpc.unary_unary_rpc_method_handler(
                    servicer.ShareFile,
                    request_deserializer=filesystem__pb2.ShareFileRequest.FromString,
                    response_serializer=filesystem__pb2.ShareFileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.filesystem.FilesystemService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FilesystemService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/GetFile',
            filesystem__pb2.GetFileRequest.SerializeToString,
            filesystem__pb2.GetFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadPresigned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/UploadPresigned',
            filesystem__pb2.UploadPresignedRequest.SerializeToString,
            filesystem__pb2.UploadPresignedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportUploadStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/ReportUploadStatus',
            filesystem__pb2.ReportUploadStatusRequest.SerializeToString,
            filesystem__pb2.ReportUploadStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/CancelUpload',
            filesystem__pb2.CancelUploadRequest.SerializeToString,
            filesystem__pb2.CancelUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/CompleteUpload',
            filesystem__pb2.CompleteUploadRequest.SerializeToString,
            filesystem__pb2.CompleteUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadPresigned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/DownloadPresigned',
            filesystem__pb2.DownloadPresignedRequest.SerializeToString,
            filesystem__pb2.DownloadPresignedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/DeleteFile',
            filesystem__pb2.DeleteFileRequest.SerializeToString,
            filesystem__pb2.DeleteFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFolder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/ListFolder',
            filesystem__pb2.ListFolderRequest.SerializeToString,
            filesystem__pb2.ListFolderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBlobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/ListBlobs',
            filesystem__pb2.ListBlobsRequest.SerializeToString,
            filesystem__pb2.ListBlobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/GetBlob',
            filesystem__pb2.GetBlobRequest.SerializeToString,
            filesystem__pb2.GetBlobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetBlobStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/SetBlobStatus',
            filesystem__pb2.SetBlobStatusRequest.SerializeToString,
            filesystem__pb2.SetBlobStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBlobPointers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/ListBlobPointers',
            filesystem__pb2.ListBlobPointersRequest.SerializeToString,
            filesystem__pb2.ListBlobPointersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Copy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/batchx.filesystem.FilesystemService/Copy',
            filesystem__pb2.CopyRequest.SerializeToString,
            log__pb2.LogRecord.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShareFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.filesystem.FilesystemService/ShareFile',
            filesystem__pb2.ShareFileRequest.SerializeToString,
            filesystem__pb2.ShareFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: audit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61udit.proto\x12\x0c\x62\x61tchx.audit\x1a\x0c\x63ommon.proto\"\x9a\x01\n\x05\x45vent\x12\x13\n\x0bts_creation\x18\x01 \x01(\x03\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.batchx.audit.EventType\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0e\n\x06object\x18\x07 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x08 \x01(\x03\"\xde\x05\n\x11ListEventsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x34\n\x05order\x18\x03 \x01(\x0b\x32%.batchx.audit.ListEventsRequest.Order\x12>\n\npagination\x18\x04 \x01(\x0b\x32*.batchx.audit.ListEventsRequest.Pagination\x12<\n\tfiltering\x18\x05 \x01(\x0b\x32).batchx.audit.ListEventsRequest.Filtering\x1a\x95\x01\n\x05Order\x12?\n\x08order_by\x18\x01 \x01(\x0e\x32-.batchx.audit.ListEventsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"\'\n\x07OrderBy\x12\x0f\n\x0bTS_CREATION\x10\x00\x12\x0b\n\x07\x42\x41LANCE\x10\x01\x1a\xbe\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x43\n\x07memento\x18\x02 \x01(\x0b\x32\x32.batchx.audit.ListEventsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a=\n\x07Memento\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x13\n\x0bts_creation\x18\x02 \x01(\x03\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\x03\x1a\xa6\x01\n\tFiltering\x12\x33\n\x0bts_creation\x18\x01 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12/\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x0c\n\x04user\x18\x03 \x03(\t\x12%\n\x04type\x18\x04 \x03(\x0e\x32\x17.batchx.audit.EventType\"\x80\x02\n\x12ListEventsResponse\x12\"\n\x05\x65vent\x18\x01 \x03(\x0b\x32\x13.batchx.audit.Event\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x41\n\tuser_data\x18\x04 \x03(\x0b\x32..batchx.audit.ListEventsResponse.UserDataEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01*\xb7\x06\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rFILE_DOWNLOAD\x10\x01\x12\x0f\n\x0b\x46ILE_UPLOAD\x10\x02\x12\x0f\n\x0b\x46ILE_DELETE\x10\x03\x12\r\n\tFILE_COPY\x10\x04\x12\x0e\n\nFILE_SHARE\x10\x05\x12\x10\n\x0c\x46ILE_UNSHARE\x10\x06\x12\x10\n\x0cIMAGE_IMPORT\x10\n\x12\x0f\n\x0bIMAGE_SHARE\x10\x0b\x12\x11\n\rIMAGE_UNSHARE\x10\x0c\x12\x0f\n\x0bIMAGE_CLONE\x10\r\x12\x11\n\rIMAGE_UNCLONE\x10\x0e\x12\x10\n\x0cIMAGE_DELETE\x10\x0f\x12\x15\n\x11IMAGE_SET_EXAMPLE\x10\x10\x12\x18\n\x14IMAGE_REMOVE_EXAMPLE\x10\x11\x12\x18\n\x14IMAGE_CLONE_EXAMPLES\x10\x12\x12\x1a\n\x16IMAGE_UNCLONE_EXAMPLES\x10\x13\x12\x0e\n\nJOB_LAUNCH\x10\x14\x12\x0e\n\nJOB_DELETE\x10\x15\x12\x0e\n\nJOB_CANCEL\x10\x16\x12\x13\n\x0fWORKFLOW_LAUNCH\x10\x1f\x12\x13\n\x0fWORKFLOW_DELETE\x10 \x12\x16\n\x12ORG_CHANGE_PROFILE\x10(\x12\x12\n\x0eORG_ADD_MEMBER\x10)\x12\x15\n\x11ORG_REMOVE_MEMBER\x10*\x12\x15\n\x11ORG_CHANGE_MEMBER\x10+\x12\x16\n\x12USER_LOGIN_ATTEMPT\x10\x32\x12\x18\n\x14USER_LOGIN_SUCCEEDED\x10\x33\x12\x19\n\x15USER_RECOVER_PASSWORD\x10\x34\x12 \n\x1cUSER_CHANGE_PASSWORD_ATTEMPT\x10\x35\x12\"\n\x1eUSER_CHANGE_PASSWORD_SUCCEEDED\x10\x36\x12\x17\n\x13USER_CHANGE_PROFILE\x10\x37\x12\x18\n\x14\x42LOB_DELETE_ARCHIVED\x10<\x12\x10\n\x0c\x42LOB_RESTORE\x10=\x12\x10\n\x0c\x42LOB_ARCHIVE\x10>\x12\x14\n\x10\x42LOB_DELETE_LIVE\x10?\x12\x13\n\x0f\x45NV_ADD_CREDITS\x10\x46\x12\x1b\n\x17\x45NV_TRANSFERRED_CREDITS\x10G2r\n\x0c\x41uditService\x12T\n\nListEvents\x12\x1f.batchx.audit.ListEventsRequest\x1a .batchx.audit.ListEventsResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\x03\x82\x97\"\x02\x10\x01\x42\x1d\n\x0fio.batchx.protoB\nAuditProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'audit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nAuditProto'
  _LISTEVENTSRESPONSE_USERDATAENTRY._options = None
  _LISTEVENTSRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _AUDITSERVICE._options = None
  _AUDITSERVICE._serialized_options = b'\202\227\"\002\010\003\202\227\"\002\020\001'
  _AUDITSERVICE.methods_by_name['ListEvents']._options = None
  _AUDITSERVICE.methods_by_name['ListEvents']._serialized_options = b'\220\002\001'
  _EVENTTYPE._serialized_start=1197
  _EVENTTYPE._serialized_end=2020
  _EVENT._serialized_start=44
  _EVENT._serialized_end=198
  _LISTEVENTSREQUEST._serialized_start=201
  _LISTEVENTSREQUEST._serialized_end=935
  _LISTEVENTSREQUEST_ORDER._serialized_start=424
  _LISTEVENTSREQUEST_ORDER._serialized_end=573
  _LISTEVENTSREQUEST_ORDER_ORDERBY._serialized_start=534
  _LISTEVENTSREQUEST_ORDER_ORDERBY._serialized_end=573
  _LISTEVENTSREQUEST_PAGINATION._serialized_start=576
  _LISTEVENTSREQUEST_PAGINATION._serialized_end=766
  _LISTEVENTSREQUEST_PAGINATION_MEMENTO._serialized_start=705
  _LISTEVENTSREQUEST_PAGINATION_MEMENTO._serialized_end=766
  _LISTEVENTSREQUEST_FILTERING._serialized_start=769
  _LISTEVENTSREQUEST_FILTERING._serialized_end=935
  _LISTEVENTSRESPONSE._serialized_start=938
  _LISTEVENTSRESPONSE._serialized_end=1194
  _LISTEVENTSRESPONSE_USERDATAENTRY._serialized_start=1126
  _LISTEVENTSRESPONSE_USERDATAENTRY._serialized_end=1194
  _AUDITSERVICE._serialized_start=2022
  _AUDITSERVICE._serialized_end=2136
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import job_pb2 as job__pb2
from . import log_pb2 as log__pb2


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetJob = channel.unary_unary(
                '/batchx.job.JobService/GetJob',
                request_serializer=job__pb2.GetJobRequest.SerializeToString,
                response_deserializer=job__pb2.GetJobResponse.FromString,
                )
        self.GetComputationalCost = channel.unary_unary(
                '/batchx.job.JobService/GetComputationalCost',
                request_serializer=job__pb2.GetComputationalCostRequest.SerializeToString,
                response_deserializer=job__pb2.GetComputationalCostResponse.FromString,
                )
        self.ListJobs = channel.unary_unary(
                '/batchx.job.JobService/ListJobs',
                request_serializer=job__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=job__pb2.ListJobsResponse.FromString,
                )
        self.Submit = channel.unary_unary(
                '/batchx.job.JobService/Submit',
                request_serializer=job__pb2.SubmitRequest.SerializeToString,
                response_deserializer=job__pb2.SubmitResponse.FromString,
                )
        self.Stream = channel.unary_stream(
                '/batchx.job.JobService/Stream',
                request_serializer=job__pb2.StreamRequest.SerializeToString,
                response_deserializer=job__pb2.StreamResponse.FromString,
                )
        self.GetLogs = channel.unary_stream(
                '/batchx.job.JobService/GetLogs',
                request_serializer=job__pb2.GetLogsRequest.SerializeToString,
                response_deserializer=log__pb2.LogRecord.FromString,
                )
        self.Delete = channel.unary_unary(
                '/batchx.job.JobService/Delete',
                request_serializer=job__pb2.DeleteRequest.SerializeToString,
                response_deserializer=job__pb2.DeleteResponse.FromString,
                )
        self.DeleteWorkflow = channel.unary_unary(
                '/batchx.job.JobService/DeleteWorkflow',
                request_serializer=job__pb2.DeleteWorkflowRequest.SerializeToString,
                response_deserializer=job__pb2.DeleteWorkflowResponse.FromString,
                )
        self.Cancel = channel.unary_unary(
                '/batchx.job.JobService/Cancel',
                request_serializer=job__pb2.CancelRequest.SerializeToString,
                response_deserializer=job__pb2.CancelResponse.FromString,
                )
        self.CreateWorkflow = channel.unary_unary(
                '/batchx.job.JobService/CreateWorkflow',
                request_serializer=job__pb2.CreateWorkflowRequest.SerializeToString,
                response_deserializer=job__pb2.CreateWorkflowResponse.FromString,
                )
        self.CloseWorkflow = channel.unary_unary(
                '/batchx.job.JobService/CloseWorkflow',
                request_serializer=job__pb2.CloseWorkflowRequest.SerializeToString,
                response_deserializer=job__pb2.CloseWorkflowResponse.FromString,
                )
        self.ListWorkflows = channel.unary_unary(
                '/batchx.job.JobService/ListWorkflows',
                request_serializer=job__pb2.ListWorkflowsRequest.SerializeToString,
                response_deserializer=job__pb2.ListWorkflowsResponse.FromString,
                )
        self.GetWorkflow = channel.unary_unary(
                '/batchx.job.JobService/GetWorkflow',
                request_serializer=job__pb2.GetWorkflowRequest.SerializeToString,
                response_deserializer=job__pb2.GetWorkflowResponse.FromString,
                )
        self.TagJob = channel.unary_unary(
                '/batchx.job.JobService/TagJob',
                request_serializer=job__pb2.TagJobRequest.SerializeToString,
                response_deserializer=job__pb2.TagJobResponse.FromString,
                )
        self.TagWorkflow = channel.unary_unary(
                '/batchx.job.JobService/TagWorkflow',
                request_serializer=job__pb2.TagWorkflowRequest.SerializeToString,
                response_deserializer=job__pb2.TagWorkflowResponse.FromString,
                )
        self.GetWorkflowGraph = channel.unary_unary(
                '/batchx.job.JobService/GetWorkflowGraph',
                request_serializer=job__pb2.GetWorkflowGraphRequest.SerializeToString,
                response_deserializer=job__pb2.GetWorkflowGraphResponse.FromString,
                )


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComputationalCost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Submit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWorkflow(self, request, context):
        """Workflow
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkflows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TagJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TagWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkflowGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJob,
                    request_deserializer=job__pb2.GetJobRequest.FromString,
                    response_serializer=job__pb2.GetJobResponse.SerializeToString,
            ),
            'GetComputationalCost': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComputationalCost,
                    request_deserializer=job__pb2.GetComputationalCostRequest.FromString,
                    response_serializer=job__pb2.GetComputationalCostResponse.SerializeToString,
            ),
            'ListJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobs,
                    request_deserializer=job__pb2.ListJobsRequest.FromString,
                    response_serializer=job__pb2.ListJobsResponse.SerializeToString,
            ),
            'Submit': grpc.unary_unary_rpc_method_handler(
                    servicer.Submit,
                    request_deserializer=job__pb2.SubmitRequest.FromString,
                    response_serializer=job__pb2.SubmitResponse.SerializeToString,
            ),
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=job__pb2.StreamRequest.FromString,
                    response_serializer=job__pb2.StreamResponse.SerializeToString,
            ),
            'GetLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.GetLogs,
                    request_deserializer=job__pb2.GetLogsRequest.FromString,
                    response_serializer=log__pb2.LogRecord.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=job__pb2.DeleteRequest.FromString,
                    response_serializer=job__pb2.DeleteResponse.SerializeToString,
            ),
            'DeleteWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWorkflow,
                    request_deserializer=job__pb2.DeleteWorkflowRequest.FromString,
                    response_serializer=job__pb2.DeleteWorkflowResponse.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=job__pb2.CancelRequest.FromString,
                    response_serializer=job__pb2.CancelResponse.SerializeToString,
            ),
            'CreateWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkflow,
                    request_deserializer=job__pb2.CreateWorkflowRequest.FromString,
                    response_serializer=job__pb2.CreateWorkflowResponse.SerializeToString,
            ),
            'CloseWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseWorkflow,
                    request_deserializer=job__pb2.CloseWorkflowRequest.FromString,
                    response_serializer=job__pb2.CloseWorkflowResponse.SerializeToString,
            ),
            'ListWorkflows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkflows,
                    request_deserializer=job__pb2.ListWorkflowsRequest.FromString,
                    response_serializer=job__pb2.ListWorkflowsResponse.SerializeToString,
            ),
            'GetWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkflow,
                    request_deserializer=job__pb2.GetWorkflowRequest.FromString,
                    response_serializer=job__pb2.GetWorkflowResponse.SerializeToString,
            ),
            'TagJob': grpc.unary_unary_rpc_method_handler(
                    servicer.TagJob,
                    request_deserializer=job__pb2.TagJobRequest.FromString,
                    response_serializer=job__pb2.TagJobResponse.SerializeToString,
            ),
            'TagWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.TagWorkflow,
                    request_deserializer=job__pb2.TagWorkflowRequest.FromString,
                    response_serializer=job__pb2.TagWorkflowResponse.SerializeToString,
            ),
            'GetWorkflowGraph': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkflowGraph,
                    request_deserializer=job__pb2.GetWorkflowGraphRequest.FromString,
                    response_serializer=job__pb2.GetWorkflowGraphResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.job.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/GetJob',
            job__pb2.GetJobRequest.SerializeToString,
            job__pb2.GetJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComputationalCost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/GetComputationalCost',
            job__pb2.GetComputationalCostRequest.SerializeToString,
            job__pb2.GetComputationalCostResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/ListJobs',
            job__pb2.ListJobsRequest.SerializeToString,
            job__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Submit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/Submit',
            job__pb2.SubmitRequest.SerializeToString,
            job__pb2.SubmitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/batchx.job.JobService/Stream',
            job__pb2.StreamRequest.SerializeToString,
            job__pb2.StreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/batchx.job.JobService/GetLogs',
            job__pb2.GetLogsRequest.SerializeToString,
            log__pb2.LogRecord.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/Delete',
            job__pb2.DeleteRequest.SerializeToString,
            job__pb2.DeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/DeleteWorkflow',
            job__pb2.DeleteWorkflowRequest.SerializeToString,
            job__pb2.DeleteWorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/Cancel',
            job__pb2.CancelRequest.SerializeToString,
            job__pb2.CancelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/CreateWorkflow',
            job__pb2.CreateWorkflowRequest.SerializeToString,
            job__pb2.CreateWorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloseWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/CloseWorkflow',
            job__pb2.CloseWorkflowRequest.SerializeToString,
            job__pb2.CloseWorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkflows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/ListWorkflows',
            job__pb2.ListWorkflowsRequest.SerializeToString,
            job__pb2.ListWorkflowsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/GetWorkflow',
            job__pb2.GetWorkflowRequest.SerializeToString,
            job__pb2.GetWorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TagJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/TagJob',
            job__pb2.TagJobRequest.SerializeToString,
            job__pb2.TagJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TagWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/TagWorkflow',
            job__pb2.TagWorkflowRequest.SerializeToString,
            job__pb2.TagWorkflowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkflowGraph(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.job.JobService/GetWorkflowGraph',
            job__pb2.GetWorkflowGraphRequest.SerializeToString,
            job__pb2.GetWorkflowGraphResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
